CMF Actors
==========

**Site Manager** --
  This actor is responsible for implementing site policies such as security,
  workflow associations, metadata and syndication policies. The Site Manager
  is also responsible for the overall organizational structure of the site.
  See :doc:`Actor_SiteManager`.

**Membership Manager** --
  This actor is responsible for managing who has access to a site
  (particularly back-end line of business users), and controls the privileges
  and properties of users. See :doc:`Actor_MembershipManager`.

**Site Developer** --
  This actor is responsible for implementing new functionality for a site and
  making changes to existing site capabilities. This is a "programmer" type
  of role, and users acting the Site Developer capacity are technical people.
  See :doc:`Actor_SiteDeveloper`.

**Add-on Developer** --
  This actor is responsible for implementing new functionality that is
  suitable for distribution to one or more sites. ** See :doc:`Actor_AddOnDeveloper`.

**Site Designer** --
  The Site Designer is responsible for producing and maintaining the "look
  and feel" of a site. This includes graphics, layout, navigation and other
  human factors. See :doc:`Actor_SiteDesigner`.

**Workflow Designer** --
  The Workflow Designer is responsible for defining new workflows and
  customizing existing workflows to meet business goals. See
  :doc:`Actor_WorkflowDesigner`.

**Content Creator** --
  Content Creators are responsible for producing and maintaining the actual
  content of a site. :doc:`Actor_ContentCreator`.

**Reviewer** --
  This actor is responsible for ensuring the quality and correctness of site
  content. See :doc:`Actor_Reviewer`.

**Site Visitor** --
  A Site Visitor is an "end user" of the site. The visitor may or may not
  have an identity known to the system. Visitors with a known identity are
  referred to as "Members" of the site, and often can do more on a site than
  visitors without a known identity ("Guests"). Member visitors often have a
  participatory role on the site. Site Visitors have some general goals that
  are applicable to most sites, but many of the specific goals and
  expectations of Site Visitors are dependent upon the specific CMF site. See
  :doc:`Actor_SiteVisitor`.
